==> localize-router-lazy-universal-module-loader-1.0.0.tgz: package/src/lazy-universal-module-loader.js <==
/**
 * Inspired by :
 * - https://github.com/angular/universal/blob/1916fec006191d63bb8b923f04179f056e39dc60/modules/module-map-ngfactory-loader/src/module-map-ngfactory-loader.ts
 * - https://github.com/Greentube/localize-router/blob/master/src/localize-router-config-loader.ts
 */
import { Injectable, Inject, Compiler, forwardRef } from '@angular/core';
import { MODULE_MAP } from '@nguniversal/module-map-ngfactory-loader';
import { ROUTES } from '@angular/router';
import { LocalizeParser } from 'localize-router';
/**
 * NgModuleFactoryLoader which does not lazy load
 */
var LazyUniversalModuleLoader = (function () {
    function LazyUniversalModuleLoader(localize, compiler, moduleMap) {
        this.localize = localize;
        this.compiler = compiler;
        this.moduleMap = moduleMap;
    }
    LazyUniversalModuleLoader.prototype.load = function (loadChildrenString) {
        var _this = this;
        var offlineMode = this.compiler instanceof Compiler;
        var type = this.moduleMap[loadChildrenString];
        if (!type) {
            throw new Error(loadChildrenString + " did not exist in the MODULE_MAP");
        }
        return (offlineMode ?
            this.loadFactory(type) : this.loadAndCompile(type))
            .then(function (factory) { return _this.localizeFactory(factory); });
    };
    LazyUniversalModuleLoader.prototype.loadFactory = function (factory) {
        return new Promise(function (resolve) { return resolve(factory); });
    };
    LazyUniversalModuleLoader.prototype.loadAndCompile = function (type) {
        return this.compiler.compileModuleAsync(type);
    };
    LazyUniversalModuleLoader.prototype.localizeFactory = function (factory) {
        var _this = this;
        return {
            moduleType: factory.moduleType,
            create: function (parentInjector) {
                var module = factory.create(parentInjector);
                var getMethod = module.injector.get.bind(module.injector);
                module.injector['get'] = function (token, notFoundValue) {
                    var getResult = getMethod(token, notFoundValue);
                    if (token === ROUTES) {
                        // translate lazy routes
                        return _this.localize.initChildRoutes([].concat.apply([], getResult));
                    }
                    else {
                        return getResult;
                    }
                };
                return module;
            }
        };
    };
    LazyUniversalModuleLoader.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    LazyUniversalModuleLoader.ctorParameters = function () { return [
        { type: LocalizeParser, decorators: [{ type: Inject, args: [forwardRef(function () { return LocalizeParser; }),] },] },
        { type: Compiler, },
        { type: undefined, decorators: [{ type: Inject, args: [MODULE_MAP,] },] },
    ]; };
    return LazyUniversalModuleLoader;
}());
export { LazyUniversalModuleLoader };

==> localize-router-lazy-universal-module-loader-1.0.1.tgz: package/src/lazy-universal-module-loader.js <==
/**
 * Inspired by :
 * - https://github.com/angular/universal/blob/1916fec006191d63bb8b923f04179f056e39dc60/modules/module-map-ngfactory-loader/src/module-map-ngfactory-loader.ts
 * - https://github.com/Greentube/localize-router/blob/master/src/localize-router-config-loader.ts
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { Injectable, Inject, Compiler, forwardRef } from '@angular/core';
import { MODULE_MAP } from '@nguniversal/module-map-ngfactory-loader';
import { ROUTES } from '@angular/router';
import { LocalizeParser } from 'localize-router';
/**
 * NgModuleFactoryLoader which does not lazy load
 */
var LazyUniversalModuleLoader = /** @class */ (function () {
    function LazyUniversalModuleLoader(localize, compiler, moduleMap) {
        this.localize = localize;
        this.compiler = compiler;
        this.moduleMap = moduleMap;
    }
    LazyUniversalModuleLoader.prototype.load = function (loadChildrenString) {
        var _this = this;
        var offlineMode = this.compiler instanceof Compiler;
        var type = this.moduleMap[loadChildrenString];
        if (!type) {
            throw new Error(loadChildrenString + " did not exist in the MODULE_MAP");
        }
        return (offlineMode ?
            this.loadFactory(type) : this.loadAndCompile(type))
            .then(function (factory) { return _this.localizeFactory(factory); });
    };
    LazyUniversalModuleLoader.prototype.loadFactory = function (factory) {
        return new Promise(function (resolve) { return resolve(factory); });
    };
    LazyUniversalModuleLoader.prototype.loadAndCompile = function (type) {
        return this.compiler.compileModuleAsync(type);
    };
    LazyUniversalModuleLoader.prototype.localizeFactory = function (factory) {
        var _this = this;
        return {
            moduleType: factory.moduleType,
            create: function (parentInjector) {
                var module = factory.create(parentInjector);
                var getMethod = module.injector.get.bind(module.injector);
                module.injector['get'] = function (token, notFoundValue) {
                    var getResult = getMethod(token, notFoundValue);
                    if (token === ROUTES) {
                        // translate lazy routes
                        return _this.localize.initChildRoutes([].concat.apply([], getResult));
                    }
                    else {
                        return getResult;
                    }
                };
                return module;
            }
        };
    };
    LazyUniversalModuleLoader = __decorate([
        Injectable(),
        __param(0, Inject(forwardRef(function () { return LocalizeParser; }))),
        __param(2, Inject(MODULE_MAP)),
        __metadata("design:paramtypes", [LocalizeParser,
            Compiler, Object])
    ], LazyUniversalModuleLoader);
    return LazyUniversalModuleLoader;
}());
export { LazyUniversalModuleLoader };
